<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr" sourcelanguage="en">
  <context>
    <name>EventDialog</name>
    <message>
      <source>Event Editor</source>
      <translation>Éditeur d'Évenement</translation>
    </message>
    <message>
      <source>Label:</source>
      <translation>Étiquette :</translation>
    </message>
    <message>
      <source>Name:</source>
      <translation>Nom :</translation>
    </message>
    <message>
      <source>Type:</source>
      <translation>Type :</translation>
    </message>
    <message>
      <source>House event</source>
      <extracomment>Constant event w/ Boolean state value</extracomment>
      <translation>Événement maison</translation>
    </message>
    <message>
      <source>Basic event</source>
      <extracomment>The main analysis event (e.g., component failure)</extracomment>
      <translation>Événement de Base</translation>
    </message>
    <message>
      <source>Undeveloped</source>
      <extracomment>The basic event flavor that indicates the further developement into a gate is possible.</extracomment>
      <translation>Événement non développé</translation>
    </message>
    <message>
      <source>Conditional</source>
      <extracomment>Conditioning flavor for a basic event (used as a conditioning variable for conditional probabilities)</extracomment>
      <translation>Conditionnel</translation>
    </message>
    <message>
      <source>Gate</source>
      <extracomment>The intermediary w/ a Boolean formula as a definition. Defines the logic and interdependencies of the fault tree.</extracomment>
      <translation>Porte</translation>
    </message>
    <message>
      <source>State:</source>
      <translation>État :</translation>
    </message>
    <message>
      <source>False</source>
      <translation>Faux</translation>
    </message>
    <message>
      <source>True</source>
      <translation>Vrai</translation>
    </message>
    <message>
      <source>Expression</source>
      <translation>Expression</translation>
    </message>
    <message>
      <source>Value:</source>
      <translation>Valeur :</translation>
    </message>
    <message>
      <source>Rate:</source>
      <translation>Taux :</translation>
    </message>
    <message>
      <source>Connective:</source>
      <translation>Conjonction :</translation>
    </message>
    <message>
      <source>AND</source>
      <translation>ET</translation>
    </message>
    <message>
      <source>OR</source>
      <translation>OU</translation>
    </message>
    <message>
      <source>ATLEAST</source>
      <extracomment>VOTE, Voting OR, Combo, Combination, K/N gate</extracomment>
      <translation>AU MOINS</translation>
    </message>
    <message>
      <source>XOR</source>
      <extracomment>Exclusive OR</extracomment>
      <translation>OU exclusif</translation>
    </message>
    <message>
      <source>NOT</source>
      <translation>NON</translation>
    </message>
    <message>
      <source>NAND</source>
      <extracomment>NOT AND</extracomment>
      <translation>NON-ET</translation>
    </message>
    <message>
      <source>NOR</source>
      <extracomment>NOT OR</extracomment>
      <translation>NON-OU</translation>
    </message>
    <message>
      <source>Min:</source>
      <translation>Min :</translation>
    </message>
    <message>
      <source>Add argument with its ID</source>
      <translation type="unfinished">Add argument with its ID</translation>
    </message>
    <message>
      <source>Add Argument</source>
      <translation type="unfinished">Add Argument</translation>
    </message>
    <message>
      <source>Remove Argument</source>
      <translation type="unfinished">Remove Argument</translation>
    </message>
    <message>
      <source>Container</source>
      <translation>Conteneur</translation>
    </message>
    <message>
      <source>Fault tree:</source>
      <translation>Arbre de défaillance :</translation>
    </message>
    <message>
      <source>Model</source>
      <translation>Modèle</translation>
    </message>
    <message>
      <source>Constant</source>
      <comment>constant probability value</comment>
      <translation>Constante</translation>
    </message>
    <message>
      <source>Exponential</source>
      <comment>probability type defined w/ negative exponential formula</comment>
      <translation>Exponentielle</translation>
    </message>
    <message>
      <source>NULL</source>
      <comment>Not a null value.</comment>
      <extracomment>Pass-through, NO-OP type</extracomment>
      <translation>NULL</translation>
    </message>
  </context>
  <context>
    <name>MainWindow</name>
    <message>
      <source>&amp;Help</source>
      <translation>&amp;Aide</translation>
    </message>
    <message>
      <source>&amp;File</source>
      <translation>&amp;Fichier</translation>
    </message>
    <message>
      <source>&amp;View</source>
      <translation>&amp;Vue</translation>
    </message>
    <message>
      <source>&amp;Zoom</source>
      <translation>&amp;Zoom</translation>
    </message>
    <message>
      <source>&amp;Toolbars</source>
      <translation>&amp;Barres d'outils</translation>
    </message>
    <message>
      <source>&amp;Analysis</source>
      <translation>&amp;Analyse</translation>
    </message>
    <message>
      <source>&amp;Edit</source>
      <translation>&amp;Édition</translation>
    </message>
    <message>
      <source>Model Tool Bar</source>
      <translation type="unfinished">Model Tool Bar</translation>
    </message>
    <message>
      <source>Edit Tool Bar</source>
      <translation type="unfinished">Edit Tool Bar</translation>
    </message>
    <message>
      <source>Zoom Tool Bar</source>
      <translation type="unfinished">Zoom Tool Bar</translation>
    </message>
    <message>
      <source>Analysis Tool Bar</source>
      <translation type="unfinished">Analysis Tool Bar</translation>
    </message>
    <message>
      <source>Data</source>
      <translation>Données</translation>
    </message>
    <message>
      <source>Reports</source>
      <translation>Rapports</translation>
    </message>
    <message>
      <source>About &amp;Qt</source>
      <translation>À propos de &amp;Qt</translation>
    </message>
    <message>
      <source>About the Qt toolkit</source>
      <translation type="unfinished">About the Qt toolkit</translation>
    </message>
    <message>
      <source>About &amp;SCRAM</source>
      <translation>À propos de &amp;SCRAM</translation>
    </message>
    <message>
      <source>E&amp;xit</source>
      <translation>Q&amp;uitter</translation>
    </message>
    <message>
      <source>Exit the Application</source>
      <translation type="unfinished">Exit the Application</translation>
    </message>
    <message>
      <source>&amp;New Model</source>
      <translation type="unfinished">&amp;New Model</translation>
    </message>
    <message>
      <source>Create a New Model</source>
      <translation type="unfinished">Create a New Model</translation>
    </message>
    <message>
      <source>&amp;Open Model Files...</source>
      <translation type="unfinished">&amp;Open Model Files...</translation>
    </message>
    <message>
      <source>Open Model Files</source>
      <translation>Ouvrir Fichiers de Modèle</translation>
    </message>
    <message>
      <source>&amp;Save Model</source>
      <translation type="unfinished">&amp;Save Model</translation>
    </message>
    <message>
      <source>Save Model &amp;As...</source>
      <translation type="unfinished">Save Model &amp;As...</translation>
    </message>
    <message>
      <source>&amp;Print...</source>
      <translation>&amp;Imprimer...</translation>
    </message>
    <message>
      <source>Print</source>
      <translation>Imprimer</translation>
    </message>
    <message>
      <source>&amp;Export As...</source>
      <translation>&amp;Exporter sous...</translation>
    </message>
    <message>
      <source>Zoom &amp;In</source>
      <translation>Zoom &amp;Avant</translation>
    </message>
    <message>
      <source>Zoom &amp;Out</source>
      <translation>Zoom A&amp;rrière</translation>
    </message>
    <message>
      <source>Best &amp;Fit</source>
      <translation>Meilleur &amp;Fit</translation>
    </message>
    <message>
      <source>Run Analysis</source>
      <translation>Exécuter Analyse</translation>
    </message>
    <message>
      <source>Analysis Settings</source>
      <translation>Paramètres d'analyse</translation>
    </message>
    <message>
      <source>&amp;Model</source>
      <translation>&amp;Modèle</translation>
    </message>
    <message>
      <source>&amp;Data</source>
      <translation>&amp;Données</translation>
    </message>
    <message>
      <source>&amp;Reports</source>
      <translation>&amp;Rapports</translation>
    </message>
    <message>
      <source>Print Previe&amp;w...</source>
      <translation>A&amp;perçu d'Impression...</translation>
    </message>
    <message>
      <source>&amp;Add Element</source>
      <translation type="unfinished">&amp;Add Element</translation>
    </message>
    <message>
      <source>Re&amp;move Element</source>
      <translation type="unfinished">Re&amp;move Element</translation>
    </message>
    <message>
      <source>Export &amp;Report As...</source>
      <translation type="unfinished">Export &amp;Report As...</translation>
    </message>
    <message>
      <source>Re&amp;name Model</source>
      <translation type="unfinished">Re&amp;name Model</translation>
    </message>
    <message>
      <source>&amp;Run</source>
      <comment>execute analysis</comment>
      <translation>&amp;Exécuter</translation>
    </message>
    <message>
      <source>&amp;Settings...</source>
      <comment>analysis configuration</comment>
      <translation>&amp;Paramètres...</translation>
    </message>
    <message>
      <source>Recent &amp;Files</source>
      <translation>Fichiers &amp;Récents</translation>
    </message>
    <message>
      <source>&amp;Preferences...</source>
      <translation>&amp;Préférences...</translation>
    </message>
    <message>
      <source>&amp;Clear List</source>
      <translation type="unfinished">&amp;Clear List</translation>
    </message>
  </context>
  <context>
    <name>NameDialog</name>
    <message>
      <source>Name Edit</source>
      <translation type="unfinished">Name Edit</translation>
    </message>
    <message>
      <source>Name:</source>
      <translation>Nom :</translation>
    </message>
  </context>
  <context>
    <name>PreferencesDialog</name>
    <message>
      <source>Preferences</source>
      <translation>Préférences</translation>
    </message>
    <message>
      <source>Language:</source>
      <translation>Langue :</translation>
    </message>
    <message>
      <source>Undo limit:</source>
      <translation>Annuler la limite :</translation>
    </message>
    <message>
      <source>Auto-save:</source>
      <translation>Sauvegarde automatique :</translation>
    </message>
    <message>
      <source>min</source>
      <extracomment>Shortened time unit for &apos;minutes&apos;</extracomment>
      <translation>min</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>Set element &apos;%1&apos; label to &apos;%2&apos;</source>
      <translation type="unfinished">Set element &apos;%1&apos; label to &apos;%2&apos;</translation>
    </message>
    <message>
      <source>Modify basic event &apos;%1&apos; expression</source>
      <translation type="unfinished">Modify basic event &apos;%1&apos; expression</translation>
    </message>
    <message>
      <source>Set house event &apos;%1&apos; state to &apos;%2&apos;</source>
      <translation type="unfinished">Set house event &apos;%1&apos; state to &apos;%2&apos;</translation>
    </message>
    <message>
      <source>Update gate &apos;%1&apos; formula</source>
      <translation type="unfinished">Update gate &apos;%1&apos; formula</translation>
    </message>
    <message>
      <source>Rename model to &apos;%1&apos;</source>
      <translation type="unfinished">Rename model to &apos;%1&apos;</translation>
    </message>
    <message>
      <source>Add fault tree &apos;%1&apos;</source>
      <translation type="unfinished">Add fault tree &apos;%1&apos;</translation>
    </message>
    <message>
      <source>Remove fault tree &apos;%1&apos;</source>
      <translation type="unfinished">Remove fault tree &apos;%1&apos;</translation>
    </message>
    <message>
      <source>Rename event &apos;%1&apos; to &apos;%2&apos;</source>
      <translation type="unfinished">Rename event &apos;%1&apos; to &apos;%2&apos;</translation>
    </message>
    <message>
      <source>True</source>
      <translation>Vrai</translation>
    </message>
    <message>
      <source>False</source>
      <translation>Faux</translation>
    </message>
    <message>
      <source>Add event &apos;%1&apos;</source>
      <translation type="unfinished">Add event &apos;%1&apos;</translation>
    </message>
    <message>
      <source>Remove event &apos;%1&apos;</source>
      <translation type="unfinished">Remove event &apos;%1&apos;</translation>
    </message>
    <message>
      <source>Change the type of event &apos;%1&apos;</source>
      <translation type="unfinished">Change the type of event &apos;%1&apos;</translation>
    </message>
    <message>
      <source>IO Error</source>
      <translation>Erreur d'E/S</translation>
    </message>
    <message>
      <source>File: %1</source>
      <translation>Fichier : %1</translation>
    </message>
    <message>
      <source>Line: %1</source>
      <translation>Ligne : %1</translation>
    </message>
    <message>
      <source>MEF Container: %1</source>
      <translation>Conteneur MEF : %1</translation>
    </message>
    <message>
      <source>XML element: %1</source>
      <translation>Élément XML : %1</translation>
    </message>
    <message>
      <source>XML attribute: %1</source>
      <translation>Attribut XML : %1</translation>
    </message>
  </context>
  <context>
    <name>SettingsDialog</name>
    <message>
      <source>Analysis Settings</source>
      <translation>Paramètres d'analyse</translation>
    </message>
    <message>
      <source>Approximations</source>
      <translation>Approximations</translation>
    </message>
    <message>
      <source>Rare-event</source>
      <translation>Événement-rare</translation>
    </message>
    <message>
      <source>Analyses</source>
      <translation>Analyses</translation>
    </message>
    <message>
      <source>Prime implicants</source>
      <translation>Premier implicants</translation>
    </message>
    <message>
      <source>Probability</source>
      <translation>Probabilité</translation>
    </message>
    <message>
      <source>Importance</source>
      <translation>Importance</translation>
    </message>
    <message>
      <source>Algorithms</source>
      <translation>Algorithmes</translation>
    </message>
    <message>
      <source>Limits</source>
      <translation>Limites</translation>
    </message>
    <message>
      <source>Mission time:</source>
      <translation>Temps de mission :</translation>
    </message>
    <message>
      <source>Product order:</source>
      <translation>Ordre de produit :</translation>
    </message>
  </context>
  <context>
    <name>StartPage</name>
    <message>
      <source>Start Here</source>
      <translation>Commencez Ici</translation>
    </message>
    <message>
      <source>Start a New Model</source>
      <translation>Commencer un Nouveau Modèle</translation>
    </message>
    <message>
      <source>Open Model Files</source>
      <translation>Ouvrir Fichiers de Modèle</translation>
    </message>
    <message>
      <source>Example Models</source>
      <translation>Modèles d'Exemple</translation>
    </message>
    <message>
      <source>Recent Files</source>
      <translation>Fichiers Récents</translation>
    </message>
  </context>
  <context>
    <name>scram::gui::DiagramView</name>
    <message>
      <source>Export As</source>
      <translation>Exporter Sous</translation>
    </message>
    <message>
      <source>SVG files (*.svg);;All files (*.*)</source>
      <translation>Fichiers SVG (*.svg);;Tous les fichiers (*.*)</translation>
    </message>
  </context>
  <context>
    <name>scram::gui::EventDialog</name>
    <message>
      <source>House event</source>
      <translation type="unfinished">House event</translation>
    </message>
    <message>
      <source>The argument &apos;%1&apos; is already in formula.</source>
      <extracomment>Duplicate arguments are not allowed in a formula.</extracomment>
      <translation type="unfinished">The argument &apos;%1&apos; is already in formula.</translation>
    </message>
    <message>
      <source>The argument &apos;%1&apos; would introduce a self-cycle.</source>
      <extracomment>Self-cycle is also called a loop in a graph.</extracomment>
      <translation type="unfinished">The argument &apos;%1&apos; would introduce a self-cycle.</translation>
    </message>
    <message>
      <source>The argument &apos;%1&apos; would introduce a cycle.</source>
      <extracomment>Fault trees are acyclic graphs.</extracomment>
      <translation type="unfinished">The argument &apos;%1&apos; would introduce a cycle.</translation>
    </message>
    <message>
      <source>The event with name &apos;%1&apos; already exists.</source>
      <extracomment>Duplicate event definition in the model.</extracomment>
      <translation type="unfinished">The event with name &apos;%1&apos; already exists.</translation>
    </message>
    <message>
      <source>Name &apos;%1&apos; would introduce a self-cycle.</source>
      <translation type="unfinished">Name &apos;%1&apos; would introduce a self-cycle.</translation>
    </message>
    <message>
      <source>%1 connective requires a single argument.</source>
      <translation type="unfinished">%1 connective requires a single argument.</translation>
    </message>
    <message>
      <source>%1 connective requires 2 or more arguments.</source>
      <translation type="unfinished">%1 connective requires 2 or more arguments.</translation>
    </message>
    <message>
      <source>%1 connective requires exactly 2 arguments.</source>
      <translation type="unfinished">%1 connective requires exactly 2 arguments.</translation>
    </message>
    <message>
      <source>Fault tree &apos;%1&apos; is already defined with a top gate.</source>
      <extracomment>Fault tree redefinition.</extracomment>
      <translation type="unfinished">Fault tree &apos;%1&apos; is already defined with a top gate.</translation>
    </message>
    <message numerus="yes">
      <source>%1 connective requires at-least %n arguments.</source>
      <extracomment>The number of required arguments is always more than 2.</extracomment>
      <translation type="unfinished">
        <numerusform>%1 connective requires at-least %n arguments.</numerusform>
        <numerusform>%1 connective requires at-least %n arguments.</numerusform>
      </translation>
    </message>
  </context>
  <context>
    <name>scram::gui::MainWindow</name>
    <message>
      <source>Validation Error</source>
      <translation type="unfinished">Validation Error</translation>
    </message>
    <message>
      <source>Not all basic events have expressions for probability analysis.</source>
      <translation type="unfinished">Not all basic events have expressions for probability analysis.</translation>
    </message>
    <message>
      <source>Running analysis...</source>
      <extracomment>This is a message shown during the analysis run.</extracomment>
      <translation type="unfinished">Running analysis...</translation>
    </message>
    <message>
      <source>Configuration Error</source>
      <translation>Erreur de configuration</translation>
    </message>
    <message>
      <source>Initialization Error</source>
      <extracomment>The error upon initialization from a file.</extracomment>
      <translation>Erreur d'initialisation</translation>
    </message>
    <message>
      <source>Fault tree &apos;%1&apos; must have a single top-gate.</source>
      <extracomment>Single top/root event fault tree are expected by GUI.</extracomment>
      <translation type="unfinished">Fault tree &apos;%1&apos; must have a single top-gate.</translation>
    </message>
    <message>
      <source>Find/Filter (Perl Regex)</source>
      <extracomment>The search bar.</extracomment>
      <translation type="unfinished">Find/Filter (Perl Regex)</translation>
    </message>
    <message>
      <source>About SCRAM</source>
      <translation>À propos de SCRAM</translation>
    </message>
    <message>
      <source>Undo:</source>
      <translation>Annuler :</translation>
    </message>
    <message>
      <source>Redo:</source>
      <translation>Refaire :</translation>
    </message>
    <message>
      <source>Save Model?</source>
      <translation type="unfinished">Save Model?</translation>
    </message>
    <message>
      <source>Save changes to model &apos;%1&apos; before closing?</source>
      <translation type="unfinished">Save changes to model &apos;%1&apos; before closing?</translation>
    </message>
    <message>
      <source>Open Model Files</source>
      <translation>Ouvrir Fichiers de Modèle</translation>
    </message>
    <message>
      <source>Model Exchange Format</source>
      <translation type="unfinished">Model Exchange Format</translation>
    </message>
    <message>
      <source>All files</source>
      <translation>Tous les fichiers</translation>
    </message>
    <message>
      <source>Save Model As</source>
      <translation type="unfinished">Save Model As</translation>
    </message>
    <message>
      <source>Export Report As</source>
      <translation type="unfinished">Export Report As</translation>
    </message>
    <message>
      <source>Dependency Container Removal</source>
      <extracomment>The container w/ dependents still in the model.</extracomment>
      <translation type="unfinished">Dependency Container Removal</translation>
    </message>
    <message>
      <source>Fault tree &apos;%1&apos; with root &apos;%2&apos; is not removable because it has dependent non-root gates. Remove the gates from the fault tree before this operation.</source>
      <translation type="unfinished">Fault tree &apos;%1&apos; with root &apos;%2&apos; is not removable because it has dependent non-root gates. Remove the gates from the fault tree before this operation.</translation>
    </message>
    <message>
      <source>Remove fault tree &apos;%1&apos; with root &apos;%2&apos;</source>
      <translation type="unfinished">Remove fault tree &apos;%1&apos; with root &apos;%2&apos;</translation>
    </message>
    <message>
      <source>Dependency Event Removal</source>
      <extracomment>The event w/ dependents in the model.</extracomment>
      <translation type="unfinished">Dependency Event Removal</translation>
    </message>
    <message>
      <source>Event &apos;%1&apos; is not removable because it has dependents. Remove the event from the dependents before this operation.</source>
      <translation type="unfinished">Event &apos;%1&apos; is not removable because it has dependents. Remove the event from the dependents before this operation.</translation>
    </message>
    <message>
      <source>Add fault tree &apos;%1&apos; with gate &apos;%2&apos;</source>
      <extracomment>Addition of a fault by defining its root event first.</extracomment>
      <translation type="unfinished">Add fault tree &apos;%1&apos; with gate &apos;%2&apos;</translation>
    </message>
    <message>
      <source>Gates</source>
      <extracomment>The tab for the table of gates.</extracomment>
      <translation>Portes</translation>
    </message>
    <message>
      <source>Basic Events</source>
      <extracomment>The tab for the table of basic events.</extracomment>
      <translation>Événements de base</translation>
    </message>
    <message>
      <source>House Events</source>
      <extracomment>The tab for the table of house events.</extracomment>
      <translation>Événements maison</translation>
    </message>
    <message>
      <source>Fault Tree: %1</source>
      <extracomment>The tab for a fault tree diagram.</extracomment>
      <translation>Arbre de défaillance : %1</translation>
    </message>
    <message>
      <source>Products: %1</source>
      <translation>Produits : %1</translation>
    </message>
    <message>
      <source>Importance: %1</source>
      <translation>Importance : %1</translation>
    </message>
    <message>
      <source>&lt;h1&gt;SCRAM %1&lt;/h1&gt;The GUI front-end for SCRAM,&lt;br/&gt;a command-line risk analysis multi-tool.&lt;br/&gt;&lt;br/&gt;License: GPLv3+&lt;br/&gt;Homepage: &lt;a href=&quot;%2&quot;&gt;%2&lt;/a&gt;&lt;br/&gt;Technical Support: &lt;a href=&quot;%3&quot;&gt;%3&lt;/a&gt;&lt;br/&gt;Bug Tracker: &lt;a href=&quot;%4&quot;&gt;%4&lt;/a&gt;&lt;br/&gt;&lt;br/&gt;%5</source>
      <translation type="unfinished">&lt;h1&gt;SCRAM %1&lt;/h1&gt;The GUI front-end for SCRAM,&lt;br/&gt;a command-line risk analysis multi-tool.&lt;br/&gt;&lt;br/&gt;License: GPLv3+&lt;br/&gt;Homepage: &lt;a href=&quot;%2&quot;&gt;%2&lt;/a&gt;&lt;br/&gt;Technical Support: &lt;a href=&quot;%3&quot;&gt;%3&lt;/a&gt;&lt;br/&gt;Bug Tracker: &lt;a href=&quot;%4&quot;&gt;%4&lt;/a&gt;&lt;br/&gt;&lt;br/&gt;%5</translation>
    </message>
    <message>
      <source>Configuration file error</source>
      <translation>Erreur de fichier de configuration</translation>
    </message>
    <message>
      <source>XML Validity Error</source>
      <translation>Erreur de validité XML</translation>
    </message>
    <message>
      <source>Invalid configuration file</source>
      <translation>Fichier de configuration non valide</translation>
    </message>
    <message>
      <source>Invalid configurations</source>
      <translation>Configurations invalides</translation>
    </message>
    <message>
      <source>Input file error</source>
      <translation type="unfinished">Input file error</translation>
    </message>
    <message>
      <source>Invalid input file</source>
      <translation type="unfinished">Invalid input file</translation>
    </message>
    <message>
      <source>Invalid input model</source>
      <translation type="unfinished">Invalid input model</translation>
    </message>
    <message>
      <source>Unnamed Model</source>
      <translation type="unfinished">Unnamed Model</translation>
    </message>
    <message>
      <source>Save error</source>
      <comment>error on saving to file</comment>
      <translation type="unfinished">Save error</translation>
    </message>
    <message>
      <source>Reporting error</source>
      <translation type="unfinished">Reporting error</translation>
    </message>
  </context>
  <context>
    <name>scram::gui::ModelTree</name>
    <message>
      <source>Fault Trees (%L1)</source>
      <extracomment>The parent item for collections of fault trees in the model.</extracomment>
      <translation>Arbres de défaillance (%L1)</translation>
    </message>
    <message>
      <source>Gates (%L1)</source>
      <extracomment>The table of gates.</extracomment>
      <translation>Portes (%L1)</translation>
    </message>
    <message>
      <source>Basic Events (%L1)</source>
      <extracomment>The table of basic events.</extracomment>
      <translation>Événements de base (%L1)</translation>
    </message>
    <message>
      <source>House Events (%L1)</source>
      <extracomment>The table of house events.</extracomment>
      <translation>Événements maison (%L1)</translation>
    </message>
  </context>
  <context>
    <name>scram::gui::PreferencesDialog</name>
    <message>
      <source>Restart Required</source>
      <translation>Redémarrage Requis</translation>
    </message>
    <message>
      <source>The language change will take effect after an application restart.</source>
      <translation type="unfinished">The language change will take effect after an application restart.</translation>
    </message>
  </context>
  <context>
    <name>scram::gui::ReportTree</name>
    <message>
      <source>Products (%L1)</source>
      <translation>Produits (%L1)</translation>
    </message>
    <message>
      <source>Probability (%1)</source>
      <translation>Probabilité (%1)</translation>
    </message>
    <message>
      <source>Importance Factors (%L1)</source>
      <translation>Facteurs d’importance (%L1)</translation>
    </message>
  </context>
  <context>
    <name>scram::gui::model::BasicEvent</name>
    <message>
      <source>Set basic event &apos;%1&apos; flavor to &apos;%2&apos;</source>
      <translation type="unfinished">Set basic event &apos;%1&apos; flavor to &apos;%2&apos;</translation>
    </message>
    <message>
      <source>Basic</source>
      <translation>Base</translation>
    </message>
    <message>
      <source>Undeveloped</source>
      <translation>Non développé</translation>
    </message>
    <message>
      <source>Conditional</source>
      <extracomment>Actually, this is &apos;conditioning&apos; since the event is the condition for some sub-tree.</extracomment>
      <translation>Conditionnel</translation>
    </message>
  </context>
  <context>
    <name>scram::gui::model::BasicEventContainerModel</name>
    <message>
      <source>ID</source>
      <translation>ID</translation>
    </message>
    <message>
      <source>Flavor</source>
      <extracomment>The flavor type of a basic event.</extracomment>
      <translation>Variante</translation>
    </message>
    <message>
      <source>Probability</source>
      <extracomment>In PRA context, probability may be unavailability or unreliability.</extracomment>
      <translation>Probabilité</translation>
    </message>
    <message>
      <source>Label</source>
      <translation>Étiquette</translation>
    </message>
  </context>
  <context>
    <name>scram::gui::model::Gate</name>
    <message>
      <source>and</source>
      <translation>et</translation>
    </message>
    <message>
      <source>or</source>
      <translation>ou</translation>
    </message>
    <message>
      <source>at-least %1</source>
      <extracomment>Also named as &apos;vote&apos;, &apos;voting or&apos;, &apos;combination&apos;, &apos;combo&apos;.</extracomment>
      <translation>au moins %1</translation>
    </message>
    <message>
      <source>xor</source>
      <translation>ou exclusif</translation>
    </message>
    <message>
      <source>not</source>
      <translation>non</translation>
    </message>
    <message>
      <source>null</source>
      <extracomment>This is &apos;pass-through&apos; or &apos;no-action&apos; gate type.</extracomment>
      <translation>null</translation>
    </message>
    <message>
      <source>nand</source>
      <extracomment>not and.</extracomment>
      <translation>non-et</translation>
    </message>
    <message>
      <source>nor</source>
      <extracomment>not or.</extracomment>
      <translation>non-ou</translation>
    </message>
  </context>
  <context>
    <name>scram::gui::model::GateContainerModel</name>
    <message>
      <source>ID</source>
      <translation>ID</translation>
    </message>
    <message>
      <source>Connective</source>
      <extracomment>Boolean operator of the Boolean formula.</extracomment>
      <translation>Conjonction</translation>
    </message>
    <message>
      <source>Args</source>
      <extracomment>The number of arguments in the Boolean formula.</extracomment>
      <translation>Args</translation>
    </message>
    <message>
      <source>Label</source>
      <translation>Étiquette</translation>
    </message>
  </context>
  <context>
    <name>scram::gui::model::HouseEventContainerModel</name>
    <message>
      <source>ID</source>
      <translation>ID</translation>
    </message>
    <message>
      <source>State</source>
      <extracomment>House event Boolean state.</extracomment>
      <translation>État</translation>
    </message>
    <message>
      <source>Label</source>
      <translation>Étiquette</translation>
    </message>
  </context>
  <context>
    <name>scram::gui::model::ImportanceTableModel</name>
    <message>
      <source>ID</source>
      <translation>ID</translation>
    </message>
    <message>
      <source>Occurrence</source>
      <translation>Occurrence</translation>
    </message>
    <message>
      <source>Probability</source>
      <translation>Probabilité</translation>
    </message>
    <message>
      <source>MIF</source>
      <translation>MIF</translation>
    </message>
    <message>
      <source>CIF</source>
      <translation>CIF</translation>
    </message>
    <message>
      <source>DIF</source>
      <translation>DIF</translation>
    </message>
    <message>
      <source>RAW</source>
      <translation>RAW</translation>
    </message>
    <message>
      <source>RRW</source>
      <translation>RRW</translation>
    </message>
  </context>
  <context>
    <name>scram::gui::model::ProductTableModel</name>
    <message>
      <source>Product</source>
      <translation>Produit</translation>
    </message>
    <message>
      <source>Order</source>
      <translation>Ordre</translation>
    </message>
    <message>
      <source>Probability</source>
      <translation>Probabilité</translation>
    </message>
    <message>
      <source>Contribution</source>
      <translation>Contribution</translation>
    </message>
  </context>
</TS>
